(()=>{"use strict";jQuery(document).ready((function(e){e("#contentview-preview a").click((function(n){e(".hide-in-preview, #section-byline, #global_statusmessage").toggle("fast"),n.preventDefault()}))})),jQuery(window).on("load",(function(e){var n=$("#plone-authentic-sources-menu").wrap("<ul class='plonetoolbar-authentic-sources-menu'>").parent();$(".personaltools-wrapper").prepend(n);var o=$("#plone-smartweb-help-menu").wrap("<ul class='plonetoolbar-smartweb-help-menu'>").parent();$(".personaltools-wrapper").prepend(o)}))})();