export default {
    // common
    'Chargement...': {
        en: 'Loading',
        fr: 'Chargement...',
    },
    "Recherche": {
        en: 'Search',
        fr: "Recherche",
    },
    "Thématiques": {
        en: 'Themes',
        fr: "Thématiques",
    },
    "Catégories": {
        en: 'Categories',
        fr: "Catégories",
    },
    "Facilités": {
        en: 'Facilities',
        fr: "Facilités",
    },
    'Plus de résultats': {
        en: 'More results',
        fr: 'Plus de résultats',
    },
    'Aucun résultat': {
        en: 'No result',
        fr: 'Aucun résultat',
    },
    'Retour': {
        en: 'Return',
        fr: 'Retour',
    },
    'Téléchargements': {
        en: 'Downloads',
        fr: 'Téléchargements',
    },
    'Billetterie': {
        en: 'Ticketing',
        fr: 'Billetterie',
    },
    'Lien vers la vidéo': {
        en: 'Link to video',
        fr: 'Lien vers la vidéo',
    },
    'Participation en ligne': {
        en: 'Join online',
        fr: 'Participation en ligne',
    },
    'Actualités trouvées': {
        en: ' News found',
        fr: ' actualités trouvées',
    },
    'Actualité trouvée': {
        en: ' News found',
        fr: ' actualité trouvée',
    },
    "Aucune actualité n'a été trouvée": {
        en: 'No news was found',
        fr: "Aucune actualité n'a été trouvée",
    },
    "Proposer une actualité": {
        en: 'Suggest a news',
        fr: "Proposer une actualité",
    },
    'événements trouvés': {
        en: ' events found',
        fr: ' événements trouvés',
    },
    'événement trouvé': {
        en: ' event found',
        fr: ' événement trouvé',
    },
    "Aucun événement n'a été trouvé": {
        en: 'No events was found',
        fr: "Aucun événement n'a été trouvé",
    },
    "Proposer un événement": {
        en: 'Suggest a event',
        fr: "Proposer un événement",
    },
    "Infos pratiques": {
        en: 'Practical information',
        fr: "Infos pratiques",
    },
    "Accessible aux PMR": {
        en: 'Je sais pas traduire',
        fr: "Accessible aux PMR",
    },
    "Lien de l'événement": {
        en: 'Event link',
        fr: "Lien de l'événement",
    },
    'contacts trouvés': {
        en: ' contact found',
        fr: ' contacts trouvés',
    },
    'contact trouvé': {
        en: ' contact found',
        fr: ' contact trouvé',
    },
    "Aucun contact n'a été trouvé": {
        en: 'No contact was found',
        fr: "Aucun contact n'a été trouvé",
    },
    "Proposer un contact": {
        en: 'Suggest a contact',
        fr: "Proposer un contact",
    },
  }
  