(()=>{"use strict";jQuery(document).ready((function(e){e(".opening_informations").click((function(s){e(this).siblings(".table_schedule").toggleClass("table_schedule--active"),s.preventDefault()})),e(document).click((function(s){e(".table_schedule").hasClass("table_schedule--active")&&(e(".table_schedule").is(s.target)||e(".opening_informations").is(s.target)||e(".table_schedule td").is(s.target)||e(".table_schedule").toggleClass("table_schedule--active"))}))})),$(document).ready((function(){const e=$("#portal-globalnav"),s=$("#subsite-navigation");function t(){e.removeClass("activated"),s.removeClass("activated"),document.body.classList.remove("submenu-open-nav-overflow"),document.documentElement.classList.remove("submenu-open-nav-overflow"),$(".show-nav").removeClass("show-nav"),$(".mask-menu").removeClass("in")}$(".close-nav").click((function(){t()})),$(document).mouseup((a=>{e.is(a.target)||0!==e.has(a.target).length||s.is(a.target)||0!==s.has(a.target).length||t()})),$("li.has_subtree > a").click((function(){return $(this).closest(e).length>0&&(!$("#portal-globalnav .show-nav").length>0&&($(e).toggleClass("activated"),$(".mask-menu").toggleClass("in")),$(this).parent().toggleClass("show-nav"),$(this).parent().find(".show-nav").toggleClass("show-nav"),$(this).parent().siblings(".show-nav").toggleClass("show-nav"),$(this).parent().find(".activated").toggleClass(".activated"),!$("#portal-globalnav .show-nav").length>0&&t()),$(this).closest(s).length>0&&(!$("#subsite-navigation .show-nav").length>0&&($(s).toggleClass("activated"),document.body.classList.add("submenu-open-nav-overflow"),document.documentElement.classList.add("submenu-open-nav-overflow")),$(this).parent().toggleClass("show-nav"),$(this).parent().find(".show-nav").toggleClass("show-nav"),$(this).parent().siblings(".show-nav").toggleClass("show-nav"),$(this).parent().find(".activated").toggleClass(".activated"),!$("#subsite-navigation .show-nav").length>0&&t()),!1})),$(".prev-nav").click((function(){$(this).closest(".show-nav").toggleClass("show-nav")}))}))})();