html, body {
	max-width: 100%;
	overflow-x: initial!important;
}
.row{
  padding: 0;
  margin: 0;
}
.breadcrumb {
	padding: 0;
}
// FOR SCROLL

body .outer-wrapper {
  & > .container{
    max-width: 100%!important;
    padding: 0!important;

  }
}
.r-annuaire-wrapper{
  @media screen and (min-width:1200px) {
    max-width: 100%;
    margin-right: inherit;
    padding-right: 0;
    padding-left: 0;
  }
}
#portal-column-content{
  padding: 0!important;
}
.r-result-filter-container{
  @media screen and (min-width:1200px) {
    position: sticky;
  }
  background: #fff;
  z-index: 1;
}
.annuaire-result-filter{
  padding: 0 .75rem;
}
#portal-column-content{
  h1{
    font-size: 0px;
    position: absolute;
  }
}
#viewlet-below-content-title,#viewlet-below-content-description{
  display: none;
}
header#content-header {
	position: sticky;
	top: 0;
  background: #fff;
}


article > header {
	margin-bottom: 0px;
}

.r-annuaire-result{
  grid-area: 1 / 1 / 3 / 2;
}
.r-map.annuaire-map{
  position: sticky;
  grid-area: 1 / 2 / 2 / 3;
}


/////////
.r-results-numbers{
  width: 100%;
  margin-bottom: 0.5rem;
  span{
    font-weight: bold;
  }
}

.r-wrapper{
  display: block;
  @media screen and (min-width:1200px){
    display: grid;
    grid-template-columns: minmax(20px, 800px) minmax(20px, 100%);
    justify-content: space-between;
    width: calc(558px + 50vw);
    margin-left: auto;
    gap: 40px;
  }
  @media screen and (min-width:1400px){
    width: calc(648px + 50vw);
  }

  .r-result{
    margin-top: 2rem;
    padding-bottom: 2rem;
    &-filter{
      display: flex;
      gap: 20px;
      .r-filter{
        width: 100%;
      }
    }
    &-list{
      padding:0;
      .r-list-item-group{
        position: relative;
        list-style: none;
        margin:1rem 0;
        .r-list-item-link{
          inset: 0px !important;
          position: absolute !important;
        }
        .r-list-item{
          display: flex;
          height: 100%;
          flex-direction: column;
          @media screen and (min-width:600px){
          flex-direction: row;
          }
          .r-item-img{
            width: 100%;
            padding-bottom: 56%;
            @media screen and (min-width:600px){
              width: 246px;
              height: 149px;
              padding-bottom: 0;
            }
            background-size: cover;
          }
          .r-item-text{
            margin-top: 0.6rem;
            @media screen and (min-width:600px){
              margin-left: 1.5rem;
              margin-top: 0;
            }
            flex-grow: 1;
            a{
              position: relative;
            }
            .r-item-title{
              font-weight: bold;
              display: block;
            }
            .r-item-categorie{
              display: block;
            }
            .r-item-all{
              display: flex;
              gap: 10px;
              .r-item-adresse{
                width: 36%;
              }
              .r-item-contact{
              }
            }
          }
        }
      }
    }
  }
  .r-map{
    @media screen and (max-width:1200px){
      margin-top: 2rem!important;
    }
    .leaflet-container{
      @media screen and (max-width:1200px){
      height: 50vh!important;
      }
    }
  }
}



// FOR BLA
.r-load-more{
  margin-bottom: 2rem;
  text-align: center;
  button{
    background: #000;
    border: solid 1px transparent;
    color: #fff;
    padding: 0.4rem 1rem;
    border-radius: 10px;
    border-bottom-left-radius: 10px;
    border-bottom-left-radius: 0px;
    font-weight: bold;
    font-size: 14px;
    margin: 0 auto;
    display: block;
    &:hover{
      background: rgba(0, 0, 0, 0.871);
    }
  }
}
.r-wrapper{
  .r-result{
    &-list{
      .r-list-item-group{

        .r-list-item-link{

        }
        .r-list-item{
          .r-item-img{
            border-radius: 15px 15px 15px 0px;
          }
          .r-item-text{
            font-size: 13px;
            &:after{
              content: "";
              width: 50px;
              height: 50px;
              background: yellow;
              border-radius: 50px;
            }
            .r-item-title{
              font-size: 18px;
            }
            .r-item-categorie{
              margin-bottom: 5px;
              text-transform: uppercase;
              color: #747474;
              font-weight: 400;
            }
            .r-item-all{
              color: #727272;

              a{
                color: #000;
              }
              .r-item-adresse{
                .itineraty{
                  margin-top: 5px;
                  &:before{
                    content: "";
                    width: 15px;
                    height: 15px;
                    display: inline-block;
                    background-size: contain;
                    background: url(../../assets/location-bla.svg) no-repeat;
                    vertical-align: middle;
                  }
                }
              }
              .r-item-contact{
                width: 100%;
              }
            }
          }
        }
      }
    }
  }
}






//////////////////////////////
.icon-baseline{
  display: inline-flex;
  align-self: center;
  margin-right: 0.4rem;
  svg{
    top: .125em;
    position: relative;
    height: 1em;
    width: 1em;
  }
}
.dpinlb{
  display: inline-block;
  vertical-align: top;
}
//// for bla ////
// content

.r-content-img{
  padding-bottom: 56.25%;
}
.r-content-title{
  margin: 1rem 0;
}
.news-info-title{
  font-weight: 700;
  margin-bottom: 1rem;
  display: block;
  color: #008FD2;
}
.r-content-news-info{
  display: flex;
  justify-content: space-between;
  margin-bottom: 2rem;
  flex-wrap: wrap;
}
.r-content-news-info-container{
  @media screen and (min-width:600px) {
    column-count: 2;
  }
  // flex-flow: column wrap;
  & > div{
    margin: 0.6rem 0;
    padding-right: 3rem;
    width: max-content;
    break-inside: avoid;
    svg{
      width: 16px;
    }
  }
  .r-content-news-info--date{
    display: flex;
    .r-content-date-start,.r-content-date-end,.r-content-date-start-hours{
      display: flex;
      flex-wrap: wrap;
    }
  }
  .r-content-news-info-social{
    svg{
      width: 30px;
      height: 30px;
    }
    ul{
      display: flex;
      align-items: center;
      margin: 0;
      li{
        list-style: none;
        a{
          &:hover{
            opacity: .7;
          }
        }
      }
    }
  }
}
.r-content-news-info-action{
  @media screen and (max-width:1000px) {
    margin-top: 1.1rem;
  }
  a{
    text-decoration: none;
  }
  & > div{
    margin: .6rem 0;
  }
  .r-content-booking{
    margin-top: 0;
    a{
      background: #000;
      color: #fff;
      padding: 0.4rem 1rem;
      text-decoration: none;
      display: block;
      border-radius: 10px;
      border-bottom-left-radius: 0px;
      font-weight: 500;
      display: flex;
      align-items: center;
      gap: 10px;
      cursor: pointer;
      svg{
        width: 22px;
        fill: white;
      }
      &:hover{
        color: #fff;
        background: rgb(63, 63, 63);

      }
    }
  }
}