const LoaderCss = () => {
        return (
            <div class="lds-roller"><div></div><div></div><div></div><div></div><div></div><div></div><div></div><div></div></div>
        )
    };

export default LoaderCss;